function batch_result1(outputfile, dir1, dir2)

% This program is used to produce segmentation performance result file
% This program assumes that one segment in segmentation result can not contain
% disjoint regions, e.g. RatioCut.
%
% outputfile: the output file that stores performance list for each image.
% dir1: the inputdata directory which contains the segmentation result
% stored as a matrix with same name as the original image and .mat
% extension. 
%
% dir2: the directory which contains the ground truth for all images.
%
% Given data: PGM files and Ground Truth with same name and ".points" extension
% Ground Truth is a polygon drawn by two undergraduate students.

% The input .mat files must be stored in the default diretory
% '../TEST_METHOD/MAT_OUT/'.
% The ground truth .point files must be stored in the directory
% '../DATA_SET/'. 

% Feng Ge, Mar 4 2005.

inputFileSuffix = 'mat';
inputFileNames = dir([dir1 '/*.' inputFileSuffix]);

numberOfFiles = size(inputFileNames,1);

fid1=fopen(outputfile,'w');


for i=1:numberOfFiles

    [path name ext] = fileparts(inputFileNames(i).name);

    I = load([dir1 '/' name '.mat']); 
    SegLabel = I.SegLabel;

    name

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    X1=[];
    Y1=[];
    filename = sprintf('%s.points',name);
    fid = fopen([dir2 '/' filename],'r');
    total_poly_points = fscanf(fid, '%d', 1);
    NoP=total_poly_points;
    for k = 1 : total_poly_points
        X1(k) = fscanf(fid, '%f', 1);
        Y1(k) = fscanf(fid, '%f', 1);
    end
    fclose(fid);
    if (X1(NoP) ~= X1(1))&(Y1(NoP) ~= Y1(1))
        NoP=NoP+1;
        X1(NoP) =X1(1);
        Y1(NoP) = Y1(1);
    end
    Xwidth=size(SegLabel,1);
    Ywidth=size(SegLabel,2);
    II=ones(Xwidth, Ywidth);
    Bw2=roipoly(II,X1,Y1);

    Ntrue=size(find(Bw2==1),1)
    Bw2=int16(Bw2);


    m=max(max(SegLabel));
    n=min(min(SegLabel));
    
    G=int16(SegLabel);

    nominator=0;
    denominator=0;
    Num_Seg=0;
    
     maxp = m;
    for l = n:m
        index = [];
        GG = zeros(size(G));
        index = find(G == l);
        GG(index(:)) = 1;
        GG = bwlabel(GG,4);

        if max(GG(:))>=2
            for j = 2:max(GG(:))
                index2 = [];
                index2= find(GG==j);
                G(index2(:))=maxp+j-1;
            end
            maxp = maxp + max(GG(:))-1;

        end

    end


    if n==0
        k=n;
        intervalue=size(find(G==k),1);
        if (intervalue>0)
            Bw=[];
            Bw=int16(ones(size(Bw2)))-Bw2;
            Num_Seg=Num_Seg+1;
            intern=size(find((G==Bw)&(G==k)),1);

            if ((intern/intervalue)>0.50)|((intern/Ntrue)>0.5)
                nominator=intern+nominator;
                denominator=intervalue+denominator;
            end
        end
        n=n+1;
    end


    for k=n:maxp
        intervalue=size(find(G==k),1);
        if (intervalue>0)
            Bw=[];
            Bw=int16(k)*Bw2;

            Num_Seg=Num_Seg+1;
            intern=size(find((G==Bw)&(G==k)),1);

            if ((intern/intervalue)>0.50)|((intern/Ntrue)>0.5)
                nominator=intern+nominator;
                denominator=intervalue+denominator;
            end

        end
    end
    
    
    Ratio=nominator/(denominator+Ntrue-nominator);
    Ratio

    if i<numberOfFiles
        fprintf(fid1, '%d ', Num_Seg);
        fprintf(fid1,'%f ',Ratio);
        fprintf(fid1,'%s\n',name);
    else
        fprintf(fid1, '%d ', Num_Seg);
        fprintf(fid1,'%f ',Ratio);
        fprintf(fid1,'%s',name);
    end

end
fclose(fid1);
clear;